@@ -667,7 +667,7 @@ void gtk_devices_remove(GtkWidget *Abtn, gpointer Adata)
     if (gtk_tree_selection_get_selected(Lselection, &Ltreemodel, &Liter)) {
       gtk_tree_model_get(Ltreemodel, &Liter, 0, &Lnum, -1);
 
-      _DEB("ON SUPIMME LE LEC = %d\n", Lnum);
+      _DEB("ON SUPRIMME LE LEC = %d\n", Lnum);
       Glistdrives = g_slist_remove(Glistdrives, g_slist_nth_data(Glistdrives, Lnum));
       gtk_list_store_remove(GTK_LIST_STORE(Ltreemodel), &Liter);
     } 
@@ -829,6 +829,11 @@ void on_selectgraveur(GtkWidget *Acombo, gpointer Adata)
     gtk_widget_set_sensitive (Lobj, DRIVE_WRITER(Ldrive));
   }
 
+  for (i=0; ((Lobj = sc_hash_table_lookupv(Lhash, "%s_notdvdrwtodisabled%d", Lname, i)) && GTK_IS_WIDGET(Lobj)); i++) {
+    /* disable si lecteur non dvdrw */
+    gtk_widget_set_sensitive (Lobj, DRIVE_DVDWRITER(Ldrive));
+  }
+
   g_free(Lspeedname);
   g_free(Llecteur);
 }
@@ -853,7 +858,8 @@ gboolean abort_gravure(GtkWidget *Abtn, gpointer Adata)
     gint *Lpid = (gint *)g_hash_table_lookup(Lhash, "pid");
     if (*Lpid) {
       /* on envoi un TERM au process (cdrecord...) pour qu'il s'arrete ! */
-      kill(*Lpid, SIGTERM);
+_DEB("kill de %d\n", *Lpid);      
+      kill(*Lpid, SIGINT);
     }
     *Labort = TRUE;
   }
@@ -894,6 +900,55 @@ void confirm_fixcd(GtkWidget *Abtn, gpointer Adata)
   }
 }
 
+/* affichage du popup "formater un dvdrw" */
+void popup_formatdvdrw(GtkWidget *Abtn, gpointer Adata)
+{
+  GtkMenu *Lpopupm = create_gtkpopupmenuformatdvd(Adata);
+  gtk_menu_popup(Lpopupm, NULL, NULL, NULL, Abtn, 0, 0);
+
+}
+
+/* confirmation d'une operation de formatage sur un dvd */
+void gtk_confirm_dvdoperation(GtkWidget *Abtn, gpointer Adata)
+{
+  const gchar *Lname = glade_get_widget_name(Abtn);
+  gchar *s, *Ltitle, *Lmessage;
+  GtkWidget *Lconfirm;
+  GHashTable *Lhash = (GHashTable *)Adata;
+  GtkWidget *Lwindow1 = GTK_WIDGET(g_hash_table_lookup(Lhash, "topwindow"));
+  gint Lrep;
+  Ttypeformatdvd Lcode;
+ 
+  g_assert(Lname);
+  if (!(s = strrchr(Lname, '_')) || !*(++s)) return;
+
+  if (!strcmp(s, "format")) {
+    Ltitle = _("Formatting DVD...");
+    Lmessage = _("Do you really want to format this media ?");
+    Lcode = DVD_FORMAT;
+  } else if (!strcmp(s, "blank")) {
+    Ltitle = _("Blanking DVD...");
+    Lmessage = _("Do you really want to fast blanking this DVD-RW ?\nBe carreful you could only write in DAO mode after a fast blanking.");
+    Lcode = DVD_BLANK;
+  } else if (!strcmp(s, "blankfull")) {
+    Ltitle = _("Full blanking DVD...");
+    Lmessage = _("Do you really want to blank this DVD-RW ?\nThis could take 1 hour with an 1x media.");
+    Lcode = DVD_FULLBLANK;
+  } else {
+    return;
+  }
+  
+  Lconfirm = gtk_message_dialog_new(GTK_WINDOW(Lwindow1),
+                      GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION,
+                      GTK_BUTTONS_YES_NO, Lmessage);
+
+  Lrep = gtk_dialog_run(GTK_DIALOG(Lconfirm));
+  gtk_widget_destroy(Lconfirm);
+  if (Lrep == GTK_RESPONSE_YES) {
+    show_dvdformatwindow(Lhash, Ltitle, Lcode);
+  }
+}
+
 /* confirmer l'effacement d'un cdrw */
 void confirm_erasecdrw(GtkWidget *Abtn, gpointer Adata)
 {
@@ -905,7 +960,7 @@ void confirm_erasecdrw(GtkWidget *Abtn, gpointer Adata)
 
   /* confirmation debut de l'operation */ 
   if (gtk_dialog_run(GTK_DIALOG(Lconfirm)) == GTK_RESPONSE_YES) {
-    gboolean Lusefastblank = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(g_hash_table_lookup(Ldialoghash, "fastblank")));
+    gboolean Lusefastblank = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(g_hash_table_lookup(Ldialoghash, "checkbox")));
     gtk_widget_destroy(Lconfirm);
     
     g_hash_table_insert(Lhash, "usefastblank", &Lusefastblank);
@@ -1260,7 +1315,8 @@ gboolean encours_callback(gpointer Adata)
   GtkProgressBar *Lprog = GTK_PROGRESS_BAR(g_hash_table_lookup(Lhash, "progress"));
   gint *Lcont = (gint *)g_hash_table_lookup(Lhash, "cont");
 
-  gtk_progress_bar_pulse(Lprog);
+  gtk_progress_bar_pulse(
+      Lprog);
 
   if ((*Lcont) == 1) (*Lcont) = 0;
   
