@@ -28,12 +28,15 @@
 #define _ERR_NO_CD  11
 #define _ERR_BUF_EMPTY 12
 #define _ERR_INAPPROPRIATE_DATA 13
-#define _ERR_INAPROPRIATE_MODE 14
+#define _ERR_INAPPROPRIATE_MODE 14
 #define _ERR_BAD_RECORDER 15
 #define _ERR_READCD 16
 #define _ERR_MKISOFS 17
 #define _ERR_INCOMPATIBLE_MEDIUM 18
 #define _ERR_CANNOT_BLANK 19
+#define _ERR_SOX 20
+#define _ERR_ALREADY_FORMAT 21
+#define _ERR_CONFIGURATION 22
 #define _ERR_UNKNOWN_ERROR 100
 
 /*
