@@ -83,6 +83,7 @@ gchar *sc_realloc_cat(gchar *Asep, gchar *Asrc, gchar *Aplus)
   return Asrc;
 }
 
+/* retourne la valeur d'un combo */
 gchar *get_combo_value(GtkWidget *Acombo)
 {
   GtkTreeModel *Lmodel = gtk_combo_box_get_model(GTK_COMBO_BOX(Acombo));
@@ -95,6 +96,7 @@ gchar *get_combo_value(GtkWidget *Acombo)
   return Lvalue;
 }
 
+/* retourne la valeur d'un combo sous forme numerique */
 gint get_combo_intvalue(GtkWidget *Acombo)
 {
   GtkTreeModel *Lmodel = gtk_combo_box_get_model(GTK_COMBO_BOX(Acombo));
@@ -199,15 +201,6 @@ GtkWidget *sc_glade_xml_get_widgetv(GladeXML *Axml, const gchar *Akeyformat, ...
   return Lreturn;
 }
 
-gchar *sc_get_filename(gchar *Afilename)
-{
-  gchar *Ltmp = _FILENAME(Afilename);
-  gchar *Lreturn = g_strescape(Ltmp, NULL);
-  g_free(Ltmp);
-
-  return Lreturn;
-}
-
 void sc_line_data_copy(GtkTreeModel *Amodel, GtkTreeIter *Aiterde, GtkTreeIter *Aitervers);
 void sc_line_data_copy(GtkTreeModel *Amodel, GtkTreeIter *Aiterde, GtkTreeIter *Aitervers)
 {
@@ -266,6 +259,64 @@ gboolean sc_str_match(gchar *Lpattern, gchar *Lstr)
 	}
 }
 
+/* copie de g_strescape present dans le fichier gstrfuncs.c
+ * sans escape des caracteres < 32 et > 128 */
+gchar * sc_strescape (const gchar *source)
+{
+  const guchar *p;
+  gchar *dest;
+  gchar *q;
+  
+  g_return_val_if_fail (source != NULL, NULL);
+
+  p = (guchar *) source;
+  /* Each source byte needs maximally four destination chars (\777) */
+  q = dest = g_malloc (strlen (source) * 4 + 1);
+
+
+  while (*p)
+    {
+      switch (*p)
+      {
+	    case '\b':
+	      *q++ = '\\';
+	      *q++ = 'b';
+	      break;
+	    case '\f':
+	      *q++ = '\\';
+	      *q++ = 'f';
+	      break;
+	    case '\n':
+	      *q++ = '\\';
+	      *q++ = 'n';
+	      break;
+	    case '\r':
+	      *q++ = '\\';
+	      *q++ = 'r';
+	      break;
+	    case '\t':
+	      *q++ = '\\';
+	      *q++ = 't';
+	      break;
+	    case '\\':
+	      *q++ = '\\';
+	      *q++ = '\\';
+	      break;
+	    case '"':
+	      *q++ = '\\';
+	      *q++ = '"';
+	      break;
+	    default:
+		*q++ = *p;
+	      break;
+	    }
+      p++;
+    }
+  *q = 0;
+  return dest;
+}
+
+
 /*
  * vim:et:ts=8:sts=2:sw=2
  */
